@@ -2,7 +2,7 @@ from datetime import datetime
 
 from analytics_client.client import Metric
 
-version_info = (0, 1, 3)
+version_info = (0, 1, 4)
 __version__ = '.'.join(map(str, version_info))
 
 
@@ -15,6 +15,11 @@ def save_metric(key, value, timestamp=None):
     Wrapper used to save a metric using a celery task.
     """
 
+    from analytics_client.settings import _ANALYTICS_ENABLED
+
+    if not _ANALYTICS_ENABLED:
+        return None
+
     from analytics_client.tasks import store_metric
 
     # Set a timestamp if it is undefined
